summaryrefslogtreecommitdiff
path: root/indra/newview/llstartup.cpp
diff options
context:
space:
mode:
authorBrad Kittenbrink <brad@lindenlab.com>2021-11-23 17:39:37 -0800
committerBrad Kittenbrink <brad@lindenlab.com>2021-11-23 17:45:22 -0800
commitd307843dd431de86e6d4c4f3e6fe8eaf946354d4 (patch)
treedae66c7682fa0addd24d1cb5cde89a4cb47b4f35 /indra/newview/llstartup.cpp
parenta1fb89ebb6e6cc89ed301b10305c145da3be295f (diff)
SL-16388 Viewer MFA Implementation
We now present MFA errors to the user during login and prompt them for an authentication token.
Diffstat (limited to 'indra/newview/llstartup.cpp')
-rw-r--r--indra/newview/llstartup.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llstartup.cpp b/indra/newview/llstartup.cpp
index f22be6481a..228d64c17b 100644
--- a/indra/newview/llstartup.cpp
+++ b/indra/newview/llstartup.cpp
@@ -1117,10 +1117,10 @@ bool idle_startup()
}
else
{
- if (reason_response != "tos")
+ if (reason_response != "tos" && reason_response != "mfa_challenge")
{
// Don't pop up a notification in the TOS case because
// LLFloaterTOS::onCancel() already scolded the user.
std::string error_code;
if(response.has("errorcode"))
{
@@ -1117,10 +1117,10 @@ bool idle_startup()
{
- // Don't pop up a notification in the TOS case because
- // LLFloaterTOS::onCancel() already scolded the user.
+ // Don't pop up a notification in the TOS or MFA cases because
+ // the specialized floater has already scolded the user.
std::string error_code;
if(response.has("errorcode"))